@@ -16,26 +16,26 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.servicecontrol_v1.types import check_error
-from google.cloud.servicecontrol_v1.types import service_controller
-from .transports.base import ServiceControllerTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ServiceControllerGrpcAsyncIOTransport
+from google.cloud.servicecontrol_v1.types import check_error, service_controller
+
 from .client import ServiceControllerClient
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceControllerTransport
+from .transports.grpc_asyncio import ServiceControllerGrpcAsyncIOTransport
 
 
 class ServiceControllerAsyncClient:
@@ -232,21 +232,20 @@ class ServiceControllerAsyncClient:
         permission on the specified service. For more information, see
         `Cloud IAM <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.cloud import servicecontrol_v1
 
-            def sample_check():
+            async def sample_check():
                 # Create a client
-                client = servicecontrol_v1.ServiceControllerClient()
+                client = servicecontrol_v1.ServiceControllerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicecontrol_v1.CheckRequest(
                 )
 
                 # Make the request
-                response = client.check(request=request)
+                response = await client.check(request=request)
 
                 # Handle the response
                 print(response)
@@ -287,8 +286,21 @@ class ServiceControllerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -320,21 +332,20 @@ class ServiceControllerAsyncClient:
         permission on the specified service. For more information, see
         `Google Cloud IAM <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.cloud import servicecontrol_v1
 
-            def sample_report():
+            async def sample_report():
                 # Create a client
-                client = servicecontrol_v1.ServiceControllerClient()
+                client = servicecontrol_v1.ServiceControllerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicecontrol_v1.ReportRequest(
                 )
 
                 # Make the request
-                response = client.report(request=request)
+                response = await client.report(request=request)
 
                 # Handle the response
                 print(response)
@@ -366,8 +377,21 @@ class ServiceControllerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
