@@ -13,13 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.api import distribution_pb2  # type: ignore
 import proto  # type: ignore
 
-from google.api import distribution_pb2  # type: ignore
-
-
 __protobuf__ = proto.module(
-    package="google.api.servicecontrol.v1", manifest={"Distribution",},
+    package="google.api.servicecontrol.v1",
+    manifest={
+        "Distribution",
+    },
 )
 
 
@@ -109,9 +110,18 @@ class Distribution(proto.Message):
                 num_finite_buckets, inclusive.
         """
 
-        num_finite_buckets = proto.Field(proto.INT32, number=1,)
-        width = proto.Field(proto.DOUBLE, number=2,)
-        offset = proto.Field(proto.DOUBLE, number=3,)
+        num_finite_buckets = proto.Field(
+            proto.INT32,
+            number=1,
+        )
+        width = proto.Field(
+            proto.DOUBLE,
+            number=2,
+        )
+        offset = proto.Field(
+            proto.DOUBLE,
+            number=3,
+        )
 
     class ExponentialBuckets(proto.Message):
         r"""Describing buckets with exponentially growing width.
@@ -133,9 +143,18 @@ class Distribution(proto.Message):
                 ranges from 1 to num_finite_buckets inclusive. Must be > 0.
         """
 
-        num_finite_buckets = proto.Field(proto.INT32, number=1,)
-        growth_factor = proto.Field(proto.DOUBLE, number=2,)
-        scale = proto.Field(proto.DOUBLE, number=3,)
+        num_finite_buckets = proto.Field(
+            proto.INT32,
+            number=1,
+        )
+        growth_factor = proto.Field(
+            proto.DOUBLE,
+            number=2,
+        )
+        scale = proto.Field(
+            proto.DOUBLE,
+            number=3,
+        )
 
     class ExplicitBuckets(proto.Message):
         r"""Describing buckets with arbitrary user-provided width.
@@ -159,25 +178,57 @@ class Distribution(proto.Message):
                 bound_size() (overflow) bound[i-1] +inf
         """
 
-        bounds = proto.RepeatedField(proto.DOUBLE, number=1,)
+        bounds = proto.RepeatedField(
+            proto.DOUBLE,
+            number=1,
+        )
 
-    count = proto.Field(proto.INT64, number=1,)
-    mean = proto.Field(proto.DOUBLE, number=2,)
-    minimum = proto.Field(proto.DOUBLE, number=3,)
-    maximum = proto.Field(proto.DOUBLE, number=4,)
-    sum_of_squared_deviation = proto.Field(proto.DOUBLE, number=5,)
-    bucket_counts = proto.RepeatedField(proto.INT64, number=6,)
+    count = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    mean = proto.Field(
+        proto.DOUBLE,
+        number=2,
+    )
+    minimum = proto.Field(
+        proto.DOUBLE,
+        number=3,
+    )
+    maximum = proto.Field(
+        proto.DOUBLE,
+        number=4,
+    )
+    sum_of_squared_deviation = proto.Field(
+        proto.DOUBLE,
+        number=5,
+    )
+    bucket_counts = proto.RepeatedField(
+        proto.INT64,
+        number=6,
+    )
     linear_buckets = proto.Field(
-        proto.MESSAGE, number=7, oneof="bucket_option", message=LinearBuckets,
+        proto.MESSAGE,
+        number=7,
+        oneof="bucket_option",
+        message=LinearBuckets,
     )
     exponential_buckets = proto.Field(
-        proto.MESSAGE, number=8, oneof="bucket_option", message=ExponentialBuckets,
+        proto.MESSAGE,
+        number=8,
+        oneof="bucket_option",
+        message=ExponentialBuckets,
     )
     explicit_buckets = proto.Field(
-        proto.MESSAGE, number=9, oneof="bucket_option", message=ExplicitBuckets,
+        proto.MESSAGE,
+        number=9,
+        oneof="bucket_option",
+        message=ExplicitBuckets,
     )
     exemplars = proto.RepeatedField(
-        proto.MESSAGE, number=10, message=distribution_pb2.Distribution.Exemplar,
+        proto.MESSAGE,
+        number=10,
+        message=distribution_pb2.Distribution.Exemplar,
     )
 
 
